import { Injectable } from "@angular/core";
import { HttpClient, HttpParams, HttpResponse } from "@angular/common/http";
import { EnvService } from "../../env/env.service";
import { Observable } from "rxjs";
import { CapabilityRequest } from "../model/capability-request";
import { CapabilityExecution } from "../model/capability-execution";

@Injectable({
  providedIn: "root",
})
export class CapabilityLauncherService {
  private endpoint = "capability/request";

  constructor(private httpClient: HttpClient, private env: EnvService) {}

  /**
   * Create capability request and send it to capability service
   * @param: capabilityName  Name of capability to create request for
   * @param: args  Arguments for capability execution
   */
  createRequest(
    capabilityName: string,
    args: string
  ): Observable<CapabilityRequest> {
    const url = this.env.workspacesUrl + this.endpoint;
    const params = JSON.stringify({ capability: capabilityName, args: args });
    return this.httpClient.post<CapabilityRequest>(url, params);
  }

  /**
   * Submit capability request
   * @param: requestId  ID of capability request to submit
   */
  submit(requestId: string): Observable<CapabilityExecution> {
    const url = `${this.env.workspacesUrl}${this.endpoint}/${requestId}/submit`;
    return this.httpClient.post<CapabilityExecution>(url, null);
  }
}
